Enum redust_resp::Data
source · [−]pub enum Data<'a> {
SimpleString(Cow<'a, str>),
Integer(i64),
BulkString(Cow<'a, [u8]>),
Array(Vec<Data<'a>>),
Null,
}Expand description
RESP data. Read the Redis documenation for details on which type to expect as a response.
Both Data::BulkString and Data::Array can represent nulls in RESP, but in this representation they are not optional. They will be represented with Data::Null if the bulk string or array is null.
Errors are not represented here for two reasons: 1) it’s never correct to send an error to the Redis server, and 2) it’s more ergonomic to have errors returned in a Result.
Since errors are not represented, it’s possible to convert a Rust string into Data without
ambiguity.
Variants
SimpleString(Cow<'a, str>)
Integer(i64)
BulkString(Cow<'a, [u8]>)
Array(Vec<Data<'a>>)
Null
Implementations
sourceimpl<'a> Data<'a>
impl<'a> Data<'a>
sourcepub fn simple_string<T>(str: &'a T) -> Self where
T: AsRef<str> + ?Sized,
pub fn simple_string<T>(str: &'a T) -> Self where
T: AsRef<str> + ?Sized,
Convenience method to create a Data::SimpleString.
sourcepub fn bulk_string<T>(bytes: &'a T) -> Self where
T: AsRef<[u8]> + ?Sized,
pub fn bulk_string<T>(bytes: &'a T) -> Self where
T: AsRef<[u8]> + ?Sized,
Convenience method to create a Data::BulkString.
sourcepub fn into_owned(self) -> Data<'static>
pub fn into_owned(self) -> Data<'static>
Convert this data into owned data.