Struct redust_resp::Serializer
source · [−]pub struct Serializer<W> {
pub output: W,
pub options: Options,
}Expand description
RESP serializer.
Fields
output: Woptions: OptionsTrait Implementations
sourceimpl<W: Default> Default for Serializer<W>
impl<W: Default> Default for Serializer<W>
sourcefn default() -> Serializer<W>
fn default() -> Serializer<W>
Returns the “default value” for a type. Read more
sourceimpl<'a, W> SerializeMap for &'a mut Serializer<W> where
W: Write,
impl<'a, W> SerializeMap for &'a mut Serializer<W> where
W: Write,
sourceimpl<'a, W> SerializeSeq for &'a mut Serializer<W> where
W: Write,
impl<'a, W> SerializeSeq for &'a mut Serializer<W> where
W: Write,
sourceimpl<'a, W> SerializeStruct for &'a mut Serializer<W> where
W: Write,
impl<'a, W> SerializeStruct for &'a mut Serializer<W> where
W: Write,
sourceimpl<'a, W> SerializeStructVariant for &'a mut Serializer<W> where
W: Write,
impl<'a, W> SerializeStructVariant for &'a mut Serializer<W> where
W: Write,
sourceimpl<'a, W> SerializeTuple for &'a mut Serializer<W> where
W: Write,
impl<'a, W> SerializeTuple for &'a mut Serializer<W> where
W: Write,
sourceimpl<'a, W> SerializeTupleStruct for &'a mut Serializer<W> where
W: Write,
impl<'a, W> SerializeTupleStruct for &'a mut Serializer<W> where
W: Write,
sourceimpl<'a, W> SerializeTupleVariant for &'a mut Serializer<W> where
W: Write,
impl<'a, W> SerializeTupleVariant for &'a mut Serializer<W> where
W: Write,
sourceimpl<'a, W> Serializer for &'a mut Serializer<W> where
W: Write,
impl<'a, W> Serializer for &'a mut Serializer<W> where
W: Write,
type Ok = ()
type Ok = ()
The output type produced by this Serializer during successful
serialization. Most serializers that produce text or binary output
should set Ok = () and serialize into an io::Write or buffer
contained within the Serializer instance. Serializers that build
in-memory data structures may be simplified by using Ok to propagate
the data structure around. Read more
type SerializeSeq = &'a mut Serializer<W>
type SerializeSeq = &'a mut Serializer<W>
Type returned from serialize_seq for serializing the content of the
sequence. Read more
type SerializeTuple = &'a mut Serializer<W>
type SerializeTuple = &'a mut Serializer<W>
Type returned from serialize_tuple for serializing the content of
the tuple. Read more
type SerializeTupleStruct = &'a mut Serializer<W>
type SerializeTupleStruct = &'a mut Serializer<W>
Type returned from serialize_tuple_struct for serializing the
content of the tuple struct. Read more
type SerializeTupleVariant = &'a mut Serializer<W>
type SerializeTupleVariant = &'a mut Serializer<W>
Type returned from serialize_tuple_variant for serializing the
content of the tuple variant. Read more
type SerializeMap = &'a mut Serializer<W>
type SerializeMap = &'a mut Serializer<W>
Type returned from serialize_map for serializing the content of the
map. Read more
type SerializeStruct = &'a mut Serializer<W>
type SerializeStruct = &'a mut Serializer<W>
Type returned from serialize_struct for serializing the content of
the struct. Read more
type SerializeStructVariant = &'a mut Serializer<W>
type SerializeStructVariant = &'a mut Serializer<W>
Type returned from serialize_struct_variant for serializing the
content of the struct variant. Read more
sourcefn serialize_bool(self, v: bool) -> Result<Self::Ok, Self::Error>
fn serialize_bool(self, v: bool) -> Result<Self::Ok, Self::Error>
Serialize a bool value. Read more
sourcefn serialize_i16(self, v: i16) -> Result<Self::Ok, Self::Error>
fn serialize_i16(self, v: i16) -> Result<Self::Ok, Self::Error>
Serialize an i16 value. Read more
sourcefn serialize_i32(self, v: i32) -> Result<Self::Ok, Self::Error>
fn serialize_i32(self, v: i32) -> Result<Self::Ok, Self::Error>
Serialize an i32 value. Read more
sourcefn serialize_i64(self, v: i64) -> Result<Self::Ok, Self::Error>
fn serialize_i64(self, v: i64) -> Result<Self::Ok, Self::Error>
Serialize an i64 value. Read more
sourcefn serialize_u16(self, v: u16) -> Result<Self::Ok, Self::Error>
fn serialize_u16(self, v: u16) -> Result<Self::Ok, Self::Error>
Serialize a u16 value. Read more
sourcefn serialize_u32(self, v: u32) -> Result<Self::Ok, Self::Error>
fn serialize_u32(self, v: u32) -> Result<Self::Ok, Self::Error>
Serialize a u32 value. Read more
sourcefn serialize_u64(self, v: u64) -> Result<Self::Ok, Self::Error>
fn serialize_u64(self, v: u64) -> Result<Self::Ok, Self::Error>
Serialize a u64 value. Read more
sourcefn serialize_f32(self, v: f32) -> Result<Self::Ok, Self::Error>
fn serialize_f32(self, v: f32) -> Result<Self::Ok, Self::Error>
Serialize an f32 value. Read more
sourcefn serialize_f64(self, v: f64) -> Result<Self::Ok, Self::Error>
fn serialize_f64(self, v: f64) -> Result<Self::Ok, Self::Error>
Serialize an f64 value. Read more
sourcefn serialize_char(self, v: char) -> Result<Self::Ok, Self::Error>
fn serialize_char(self, v: char) -> Result<Self::Ok, Self::Error>
Serialize a character. Read more
sourcefn serialize_bytes(self, v: &[u8]) -> Result<Self::Ok, Self::Error>
fn serialize_bytes(self, v: &[u8]) -> Result<Self::Ok, Self::Error>
Serialize a chunk of raw byte data. Read more
sourcefn serialize_some<T: ?Sized>(self, value: &T) -> Result<Self::Ok, Self::Error> where
T: Serialize,
fn serialize_some<T: ?Sized>(self, value: &T) -> Result<Self::Ok, Self::Error> where
T: Serialize,
sourcefn serialize_unit_struct(
self,
_name: &'static str
) -> Result<Self::Ok, Self::Error>
fn serialize_unit_struct(
self,
_name: &'static str
) -> Result<Self::Ok, Self::Error>
Serialize a unit struct like struct Unit or PhantomData<T>. Read more
sourcefn serialize_unit_variant(
self,
_name: &'static str,
_variant_index: u32,
variant: &'static str
) -> Result<Self::Ok, Self::Error>
fn serialize_unit_variant(
self,
_name: &'static str,
_variant_index: u32,
variant: &'static str
) -> Result<Self::Ok, Self::Error>
Serialize a unit variant like E::A in enum E { A, B }. Read more
sourcefn serialize_newtype_struct<T: ?Sized>(
self,
_name: &'static str,
value: &T
) -> Result<Self::Ok, Self::Error> where
T: Serialize,
fn serialize_newtype_struct<T: ?Sized>(
self,
_name: &'static str,
value: &T
) -> Result<Self::Ok, Self::Error> where
T: Serialize,
Serialize a newtype struct like struct Millimeters(u8). Read more
sourcefn serialize_newtype_variant<T: ?Sized>(
self,
_name: &'static str,
_variant_index: u32,
variant: &'static str,
value: &T
) -> Result<Self::Ok, Self::Error> where
T: Serialize,
fn serialize_newtype_variant<T: ?Sized>(
self,
_name: &'static str,
_variant_index: u32,
variant: &'static str,
value: &T
) -> Result<Self::Ok, Self::Error> where
T: Serialize,
Serialize a newtype variant like E::N in enum E { N(u8) }. Read more
sourcefn serialize_seq(
self,
len: Option<usize>
) -> Result<Self::SerializeSeq, Self::Error>
fn serialize_seq(
self,
len: Option<usize>
) -> Result<Self::SerializeSeq, Self::Error>
Begin to serialize a variably sized sequence. This call must be
followed by zero or more calls to serialize_element, then a call to
end. Read more
sourcefn serialize_tuple(
self,
len: usize
) -> Result<Self::SerializeTuple, Self::Error>
fn serialize_tuple(
self,
len: usize
) -> Result<Self::SerializeTuple, Self::Error>
Begin to serialize a statically sized sequence whose length will be
known at deserialization time without looking at the serialized data.
This call must be followed by zero or more calls to serialize_element,
then a call to end. Read more
sourcefn serialize_tuple_struct(
self,
_name: &'static str,
len: usize
) -> Result<Self::SerializeTupleStruct, Self::Error>
fn serialize_tuple_struct(
self,
_name: &'static str,
len: usize
) -> Result<Self::SerializeTupleStruct, Self::Error>
Begin to serialize a tuple struct like struct Rgb(u8, u8, u8). This
call must be followed by zero or more calls to serialize_field, then a
call to end. Read more
sourcefn serialize_tuple_variant(
self,
_name: &'static str,
_variant_index: u32,
variant: &'static str,
len: usize
) -> Result<Self::SerializeTupleVariant, Self::Error>
fn serialize_tuple_variant(
self,
_name: &'static str,
_variant_index: u32,
variant: &'static str,
len: usize
) -> Result<Self::SerializeTupleVariant, Self::Error>
Begin to serialize a tuple variant like E::T in enum E { T(u8, u8) }. This call must be followed by zero or more calls to
serialize_field, then a call to end. Read more
sourcefn serialize_map(
self,
len: Option<usize>
) -> Result<Self::SerializeMap, Self::Error>
fn serialize_map(
self,
len: Option<usize>
) -> Result<Self::SerializeMap, Self::Error>
Begin to serialize a map. This call must be followed by zero or more
calls to serialize_key and serialize_value, then a call to end. Read more
sourcefn serialize_struct(
self,
_name: &'static str,
len: usize
) -> Result<Self::SerializeStruct, Self::Error>
fn serialize_struct(
self,
_name: &'static str,
len: usize
) -> Result<Self::SerializeStruct, Self::Error>
Begin to serialize a struct like struct Rgb { r: u8, g: u8, b: u8 }.
This call must be followed by zero or more calls to serialize_field,
then a call to end. Read more
sourcefn serialize_struct_variant(
self,
_name: &'static str,
_variant_index: u32,
variant: &'static str,
len: usize
) -> Result<Self::SerializeStructVariant, Self::Error>
fn serialize_struct_variant(
self,
_name: &'static str,
_variant_index: u32,
variant: &'static str,
len: usize
) -> Result<Self::SerializeStructVariant, Self::Error>
Begin to serialize a struct variant like E::S in enum E { S { r: u8, g: u8, b: u8 } }. This call must be followed by zero or more calls to
serialize_field, then a call to end. Read more
sourcefn serialize_i128(self, v: i128) -> Result<Self::Ok, Self::Error>
fn serialize_i128(self, v: i128) -> Result<Self::Ok, Self::Error>
Serialize an i128 value. Read more
sourcefn serialize_u128(self, v: u128) -> Result<Self::Ok, Self::Error>
fn serialize_u128(self, v: u128) -> Result<Self::Ok, Self::Error>
Serialize a u128 value. Read more
sourcefn collect_seq<I>(self, iter: I) -> Result<Self::Ok, Self::Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Serialize,
fn collect_seq<I>(self, iter: I) -> Result<Self::Ok, Self::Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Serialize,
Collect an iterator as a sequence. Read more
sourcefn collect_map<K, V, I>(self, iter: I) -> Result<Self::Ok, Self::Error> where
K: Serialize,
V: Serialize,
I: IntoIterator<Item = (K, V)>,
fn collect_map<K, V, I>(self, iter: I) -> Result<Self::Ok, Self::Error> where
K: Serialize,
V: Serialize,
I: IntoIterator<Item = (K, V)>,
Collect an iterator as a map. Read more
sourcefn collect_str<T>(self, value: &T) -> Result<Self::Ok, Self::Error> where
T: Display + ?Sized,
fn collect_str<T>(self, value: &T) -> Result<Self::Ok, Self::Error> where
T: Display + ?Sized,
Serialize a string produced by an implementation of Display. Read more
sourcefn is_human_readable(&self) -> bool
fn is_human_readable(&self) -> bool
Determine whether Serialize implementations should serialize in
human-readable form. Read more