Module redust_resp::parser
source · [−]Expand description
RESP parsing.
Functions
Parse the length of a RESP array. Parsing the array elements is handled handled by the other parsers.
Parse a RESP bulk string.
Parse a RESP error.
Parse a RESP integer.
Parse a RESP integer, including strings and bulk strings if they are valid integers.
Parse a RESP string.
Parse a RESP string, including bulk string if the bytes are valid UTF-8.
Type Definitions
A parser error.